==> ICAMS_2.0.7.tar.gz: ICAMS/tests/testthat/test_PlotCatalogToPdf.SBS192Catalog.R <==
context("PlotCatalogToPdf.SBS192Catalog")

test_that("PlotCatalogToPdf.SBS192Catalog function", {
  catalog.counts <- ReadCatalog("testdata/regress.cat.sbs.192.csv",
                                ref.genome = "GRCh37",
                                region = "transcript", catalog.type = "counts")
  colnames(catalog.counts) <- paste0("HepG2_", 1 : 4)
  out <-
    PlotCatalogToPdf(catalog.counts, 
                     file = file.path(tempdir(), "PlotCatSBS192.counts.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.counts,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.counts.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.density <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "density")
  out <-
    PlotCatalogToPdf(catalog.density, file = file.path(tempdir(), "PlotCatSBS192.density.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.density,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.density.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.counts.signature <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "counts.signature")
  out <-
    PlotCatalogToPdf(catalog.counts.signature,
                     file = file.path(tempdir(), "PlotCatSBS192.counts.signature.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.counts.signature,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.counts.signature.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.density.signature <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "density.signature")
  out <-
    PlotCatalogToPdf(catalog.density.signature,
                     file = file.path(tempdir(), "PlotCatSBS192.density.signature.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.density.signature,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.density.signature.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  unlink(file.path(tempdir(), "PlotCatSBS192.counts.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.density.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.counts.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.density.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.counts.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.density.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.counts.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.density.signature.test.pdf"))
  graphics.off()
})

==> ICAMS_2.0.8.tar.gz: ICAMS/tests/testthat/test_PlotCatalogToPdf.SBS192Catalog.R <==
context("PlotCatalogToPdf.SBS192Catalog")

test_that("PlotCatalogToPdf.SBS192Catalog function", {
  skip_if("" == system.file(package = "BSgenome.Hsapiens.1000genomes.hs37d5"))
  stopifnot(requireNamespace("BSgenome.Hsapiens.1000genomes.hs37d5"))
  catalog.counts <- ReadCatalog("testdata/regress.cat.sbs.192.csv",
                                ref.genome = "GRCh37",
                                region = "transcript", catalog.type = "counts")
  colnames(catalog.counts) <- paste0("HepG2_", 1 : 4)
  out <-
    PlotCatalogToPdf(catalog.counts, 
                     file = file.path(tempdir(), "PlotCatSBS192.counts.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.counts,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.counts.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.density <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "density")
  out <-
    PlotCatalogToPdf(catalog.density, file = file.path(tempdir(), "PlotCatSBS192.density.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.density,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.density.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.counts.signature <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "counts.signature")
  out <-
    PlotCatalogToPdf(catalog.counts.signature,
                     file = file.path(tempdir(), "PlotCatSBS192.counts.signature.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.counts.signature,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.counts.signature.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  catalog.density.signature <-
    TransformCatalog(catalog.counts, target.ref.genome = "GRCh37",
                     target.region = "transcript",
                     target.catalog.type = "density.signature")
  out <-
    PlotCatalogToPdf(catalog.density.signature,
                     file = file.path(tempdir(), "PlotCatSBS192.density.signature.test.pdf"))
  out1 <-
    PlotCatalogToPdf(catalog.density.signature,
                     file = file.path(tempdir(), "PlotCatalog.SBS12.density.signature.test.pdf"),
                     plot.SBS12 = TRUE)
  expect_equal(out, TRUE)
  expect_equal(out1, TRUE)

  unlink(file.path(tempdir(), "PlotCatSBS192.counts.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.density.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.counts.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatSBS192.density.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.counts.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.density.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.counts.signature.test.pdf"))
  unlink(file.path(tempdir(), "PlotCatalog.SBS12.density.signature.test.pdf"))
  graphics.off()
})
